@@ -58,7 +58,7 @@ private Q_SLOTS:
     void primaryConnectionChanged(const QString & connection);
 #if WITH_MODEMMANAGER_SUPPORT
     void modemNetworkRemoved();
-    void modemSignalChanged(uint signal);
+    void modemSignalChanged(const ModemManager::SignalQualityPair &signalQuality);
     void setIconForModem();
 #endif
     void statusChanged(NetworkManager::Status status);
