@@ -88,10 +88,8 @@ void WifiConnectionWidget::loadConfig(const NetworkManager::Setting::Ptr &settin
     }
 }
 
-QVariantMap WifiConnectionWidget::setting(bool agentOwned) const
+QVariantMap WifiConnectionWidget::setting() const
 {
-    Q_UNUSED(agentOwned);
-
     NetworkManager::WirelessSetting wifiSetting;
 
     wifiSetting.setSsid(m_ui->SSIDCombo->ssid().toUtf8());
@@ -128,6 +126,11 @@ void WifiConnectionWidget::generateRandomClonedMac()
         int random = qrand() % 255;
         mac[i] = random;
     }
+
+    // Disable the multicast bit and enable the locally administered bit.
+    mac[0] = mac[0] & ~0x1;
+    mac[0] = mac[0] |  0x2;
+
     m_ui->clonedMacAddress->setText(NetworkManager::macAddressAsString(mac));
 }
 
