@@ -22,11 +22,10 @@
 #define PLASMA_NM_L2TP_H
 
 #include "vpnuiplugin.h"
-#include "plasmanm_export.h"
 
 #include <QVariant>
 
-class PLASMA_NM_EXPORT L2tpUiPlugin : public VpnUiPlugin
+class Q_DECL_EXPORT L2tpUiPlugin : public VpnUiPlugin
 {
     Q_OBJECT
 public:
