@@ -40,13 +40,12 @@ public:
     void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
     void loadSecrets(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const;
+    QVariantMap setting() const;
 
     virtual bool isValid() const;
 
 private Q_SLOTS:
     void userPasswordTypeChanged(int index);
-    void showPassword(bool show);
     void showAdvanced();
     void showPpp();
 
