@@ -46,7 +46,6 @@ StrongswanAuthWidget::StrongswanAuthWidget(const NetworkManager::VpnSetting::Ptr
     d->setting = setting;
     d->ui.setupUi(this);
     d->acceptOnShow = false;
-    connect(d->ui.chkShowPass, &QCheckBox::toggled, this, &StrongswanAuthWidget::showPasswordsChanged);
 
     readSecrets();
 
@@ -104,9 +103,8 @@ void StrongswanAuthWidget::acceptDialog()
     }
 }
 
-QVariantMap StrongswanAuthWidget::setting(bool agentOwned) const
+QVariantMap StrongswanAuthWidget::setting() const
 {
-    Q_UNUSED(agentOwned)
     Q_D(const StrongswanAuthWidget);
 
     NMStringMap secrets;
@@ -126,13 +124,3 @@ QVariantMap StrongswanAuthWidget::setting(bool agentOwned) const
     secretData.insert("secrets", QVariant::fromValue<NMStringMap>(secrets));
     return secretData;
 }
-
-void StrongswanAuthWidget::showPasswordsChanged(bool show)
-{
-    Q_D(StrongswanAuthWidget);
-    if (show) {
-        d->ui.password->setEchoMode(QLineEdit::Normal);
-    } else {
-        d->ui.password->setEchoMode(QLineEdit::Password);
-    }
-}
